@@ -530,9 +530,6 @@ def init_ap():
             '--info-only',
             action='store_true',
             help='do not perform the actual update, get the info only')
-        p.add_argument('--unsafe',
-                       action='store_true',
-                       help='skip signature verifications')
         p.add_argument('--test',
                        action='store_true',
                        help='install the build marked as test')
