@@ -61,9 +61,10 @@ class CLI:
     def server_status(self):
         eva_control_c('status')
 
-    def update(self, repository_url, yes, info_only, unsafe, test):
+    def update(self, repository_url, yes, info_only, test):
         import json
-        from .tools import safe_download, set_file_lock, remove_file_lock, get_arch, get_public_key
+        from .tools import safe_download, set_file_lock
+        from .tools import remove_file_lock, get_arch
         arch = get_arch()
         if arch.startswith('arm'):
             arch_sfx = 'armv7'
@@ -128,10 +129,6 @@ class CLI:
             manifest = json.loads(
                 safe_download(f'{repository_url}/{new_version}/nightly/'
                               f'manifest-{new_build}.json'))
-            if unsafe:
-                public_key = None
-            else:
-                public_key = get_public_key()
             if not yes:
                 if version != new_version:
                     try:
@@ -157,16 +154,31 @@ class CLI:
             update_files = [
                 update_script, f'eva-{new_version}-{new_build}-{arch_sfx}.tgz'
             ]
+            print()
+            print('Updating...')
             try:
                 os.chdir(common.dir_eva)
                 for f in update_files:
+                    url = f'{repository_url}/{new_version}/nightly/{f}'
+                    try:
+                        data = manifest['content'][f]
+                        sig = data['signature']
+                    except KeyError:
+                        raise RuntimeError(
+                            f'Signature for {url} not found in manifest')
                     with open(f, 'wb') as fh:
                         fh.write(
-                            safe_download(
-                                f'{repository_url}/{new_version}/nightly/{f}',
-                                manifest=manifest,
-                                timeout=current_command.timeout * 20,
-                                public_key=public_key))
+                            safe_download(url,
+                                          manifest=manifest,
+                                          timeout=current_command.timeout * 20))
+                    try:
+                        if os.system(f'./sbin/rsatool verify "{f}" '
+                                     f'"./share/eva.key" "{sig}" > /dev/null'):
+                            raise RuntimeError(
+                                'Signature verification error for {url}')
+                    except:
+                        os.unlink(f)
+                        raise
                 if os.system(f'bash {update_script}'):
                     err('FAILED TO APPLY UPDATE! '
                         'TRYING TO BRING THE NODE BACK ONLINE')
@@ -688,6 +700,22 @@ class CLI:
 
     def version(self):
         from . import __version__
-        d = get_node_svc_info()
-        d['cli_version'] = __version__
-        print_result(d, need_header=False, name_value=True)
+        info = get_node_svc_info()
+        if current_command.json:
+            d = {
+                'cli_version': __version__,
+                'build': info['build'],
+                'version': info['version'],
+            }
+        else:
+            d = [{
+                'name': 'version',
+                'value': info['version']
+            }, {
+                'name': 'build',
+                'value': info['build']
+            }, {
+                'name': 'CLI version',
+                'value': __version__
+            }]
+        print_result(d, need_header=False, name_value=False)
